@@ -81,6 +81,8 @@ fi
 ( cd opt/kde/lib ; ln -sf libkhtml.so.4.2.0 libkhtml.so.4 )
 ( cd opt/kde/lib ; rm -rf libkabc_dir.so.1 )
 ( cd opt/kde/lib ; ln -sf libkabc_dir.so.1.0.0 libkabc_dir.so.1 )
+( cd opt/kde/lib ; rm -rf libkunittest.so.1 )
+( cd opt/kde/lib ; ln -sf libkunittest.so.1.0.0 libkunittest.so.1 )
 ( cd opt/kde/lib ; rm -rf libDCOP.so.4 )
 ( cd opt/kde/lib ; ln -sf libDCOP.so.4.2.0 libDCOP.so.4 )
 ( cd opt/kde/lib ; rm -rf libkmdi.so.1 )
@@ -135,6 +137,8 @@ fi
 ( cd opt/kde/lib ; ln -sf libkdefakes.so.4.2.0 libkdefakes.so )
 ( cd opt/kde/lib ; rm -rf libkmediaplayer.so.0 )
 ( cd opt/kde/lib ; ln -sf libkmediaplayer.so.0.0.0 libkmediaplayer.so.0 )
+( cd opt/kde/lib ; rm -rf libkunittest.so )
+( cd opt/kde/lib ; ln -sf libkunittest.so.1.0.0 libkunittest.so )
 ( cd opt/kde/lib ; rm -rf libkspell2.so.1 )
 ( cd opt/kde/lib ; ln -sf libkspell2.so.1.0.0 libkspell2.so.1 )
 ( cd opt/kde/lib ; rm -rf libkabc_net.so.1 )
@@ -165,8 +169,6 @@ fi
 ( cd opt/kde/lib ; ln -sf libkhtml.so.4.2.0 libkhtml.so )
 ( cd opt/kde/lib ; rm -rf libkio.so.4 )
 ( cd opt/kde/lib ; ln -sf libkio.so.4.2.0 libkio.so.4 )
-( cd opt/kde/share/doc/HTML/en/kdelibs-apidocs ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kdelibs-apidocs ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kspell ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kspell ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/icons ; rm -rf default.kde )
